@@ -1,10 +1,11 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package Net::Travis::API::Auth::GitHub;
-$Net::Travis::API::Auth::GitHub::VERSION = '0.001001';
+
+our $VERSION = '0.002000';
+
 # ABSTRACT: Authorize with Travis using a GitHub token
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
@@ -87,7 +88,7 @@ Net::Travis::API::Auth::GitHub - Authorize with Travis using a GitHub token
 
 =head1 VERSION
 
-version 0.001001
+version 0.002000
 
 =head1 METHODS
 
@@ -120,11 +121,11 @@ requests as authorized by that token.
 
 =head1 AUTHOR
 
-Kent Fredric <kentfredric@gmail.com>
+Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2016 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
