@@ -1,10 +1,11 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package Net::Travis::API::Role::Client;
-$Net::Travis::API::Role::Client::VERSION = '0.001001';
+
+our $VERSION = '0.002000';
+
 # ABSTRACT: Anything that fetches from Travis and returns JSON data
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
@@ -53,7 +54,7 @@ Net::Travis::API::Role::Client - Anything that fetches from Travis and returns J
 
 =head1 VERSION
 
-version 0.001001
+version 0.002000
 
 =head1 ATTRIBUTES
 
@@ -73,11 +74,11 @@ A L<< C<Net::Travis::API::UA>|Net::Travis::API::UA >> instance for performing re
 
 =head1 AUTHOR
 
-Kent Fredric <kentfredric@gmail.com>
+Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2016 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
